@@ -5,6 +5,15 @@ from .exceptions import ResourceNotFound, ResourceExists
 
 
 class QuerySet(object):
+    """ Queryset that allows for querying, creating, updating and deleting
+    of resources.
+
+    >>> ExampleResource.objects
+    QuerySet<{'id': 'test'}, {'id': 'tast'}, ....>
+
+    >>> ExampleResource.objects.filter({'id': 'test'})
+    Queryset<{'id': 'test'}>
+    """
     def __init__(self, resource, start=0, end=None, sort=None, filter=None):
         self.resource = resource
 
@@ -93,7 +102,24 @@ class QuerySet(object):
         return result
 
     def next(self):
-        resource = self.resource(self._cursor.next())
+        data = self._cursor.next()
+
+        return self.resource(data, meta=data.pop('_meta'))
+
+    def get(self, query=None):
+        filter = dict(self._filter)
+        if query:
+            filter.update(query)
+
+        data = self.collection.find_one(
+            filter,
+            fields={'_id': False}
+        )
+
+        if data is None:
+            raise ResourceNotFound(filter)
+
+        resource = self.resource(data)
         resource.meta = resource.pop('_meta')
 
         return resource
@@ -112,7 +138,7 @@ class QuerySet(object):
 
     def insert(self, resource, validate=True):
         data = dict(resource)
-        data['_id'] = resource.url
+        data['_id'] = resource._id
         data['_meta'] = resource.meta
 
         try:
@@ -126,7 +152,7 @@ class QuerySet(object):
         data['_meta'] = resource.meta
 
         result = self.collection.update(
-            {'_id': resource.url}, data, upsert=upsert
+            {'_id': resource._id}, data, upsert=upsert
         )
 
         if result['n'] == 0:
